{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-kamailio:pyfb_kamailio_uacreg_list' %}">UacReg Listing</a></p>
<table class="table">
<tr><td>l_uuid</td><td>{{ object.l_uuid }}</td></tr>
<tr><td>l_username</td><td>{{ object.l_username }}</td></tr>
<tr><td>l_domain</td><td>{{ object.l_domain }}</td></tr>
<tr><td>r_username</td><td>{{ object.r_username }}</td></tr>
<tr><td>r_domain</td><td>{{ object.r_domain }}</td></tr>
<tr><td>realm</td><td>{{ object.realm }}</td></tr>
<tr><td>auth_username</td><td>{{ object.auth_username }}</td></tr>
<tr><td>auth_password</td><td>{{ object.auth_password }}</td></tr>
<tr><td>auth_ha1</td><td>{{ object.auth_ha1 }}</td></tr>
<tr><td>auth_proxy</td><td>{{ object.auth_proxy }}</td></tr>
<tr><td>expires</td><td>{{ object.expires }}</td></tr>
<tr><td>flags</td><td>{{ object.flags }}</td></tr>
<tr><td>reg_delay</td><td>{{ object.reg_delay }}</td></tr>
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">Edit UacReg</a>

{% endblock %}
