# Generated by Django 2.1.5 on 2019-03-06 15:14

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0006_toposd_topost'),
    ]

    operations = [
        migrations.AddField(
            model_name='missedcall',
            name='cseq',
            field=models.CharField(default='', help_text='cseq field', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='from_domain',
            field=models.CharField(default='', help_text='FROM domain field', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='from_user',
            field=models.CharField(default='', help_text='FROM user field', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='ruri_domain',
            field=models.CharField(default='', help_text='RURI domain field', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='ruri_user',
            field=models.CharField(default='', help_text='RURI user field', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='src_ip',
            field=models.CharField(default='', help_text='source IP', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='time_attr',
            field=models.IntegerField(default=1, help_text='Unix timestamp'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='missedcall',
            name='time_exten',
            field=models.IntegerField(default=0, help_text='extended value related to the time of event'),
            preserve_default=False,
        ),
    ]
